//shadi
import dotenv from 'dotenv';
dotenv.config();

import {
    getCustomerListByEmployeeNumber,
    getCustomerInfoByCustomerId,
    insertOneCustomerIntoTable,
    checkCustomerIsInTable,
    getApprovedCustomerListByEmployeeNumber,
    getApprovedAvailableCustomerListByEmployeeNumber,
    getApprovedCustomerInfoByCustomerId,
    insertSheduleIntoTable,
    checkSheduleIsInTable,
    getSheduleListByEmployeeDate,
    getCurrMonthSheduleEmployee,
    updateSheduleStatusCancel,
    updateSheduleStatusComplete,
    getSheduleCountOfCurrentMonth
} from '../db_apis/location.js';


export async function getCustomerList(req, res, next) {
    try {
        const context = {};
        context.employee_number = req.body.employee_number;

        const customerList = await getCustomerListByEmployeeNumber(context);

        res.status(200).json({
            status: 'success',
            data: customerList,
        });

    } catch (err) {
        return next(err);
    }
}


export async function getCustomerInfo(req, res, next) {
    try {
        const context = {};
        context.customer_id = req.body.customer_id;
        context.employee_number = req.body.employee_number;

        const customerInfo = await getCustomerInfoByCustomerId(context);

        res.status(200).json({
            status: 'success',
            data: customerInfo[0],
        });

    } catch (err) {
        return next(err);
    }
}


// insert
export async function insertOneCustomer(req, res, next) {
    try {
        const inserted = await insertOneCustomerIntoTable(req.body);
        if (inserted) {
            res.status(200).json({
                status: 'success',
            });
        }

    } catch (err) {
        return next(err);
    }
}


// list of approved customer by so
export async function getApprovedCustomerList(req, res, next) {
    try {
        const context = {};
        context.employee_number = req.body.employee_number;

        const customerList = await getApprovedCustomerListByEmployeeNumber(context);

        res.status(200).json({
            status: 'success',
            data: customerList,
        });

    } catch (err) {
        return next(err);
    }
}



// list of available customer list which do not have schedule  by date for create schedule page
export async function getApprovedAvailableCustomerList(req, res, next) {
    try {
        const context = {};
        context.employee_number = req.body.employee_number;
        context.selected_date = req.body.selected_date;

        const customerList = await getApprovedAvailableCustomerListByEmployeeNumber(context);
        // console.log('customerList', customerList);

        res.status(200).json({
            status: 'success',
            data: customerList,
        });

    } catch (err) {
        return next(err);
    }
}



export async function getApprovedCustomerInfo(req, res, next) {
    try {
        const context = {};
        context.customer_id = req.body.customer_id;
        context.employee_number = req.body.employee_number;

        const result = await getApprovedCustomerInfoByCustomerId(context);

        res.status(200).json({
            status: 'success',
            data: result[0],
        });

    } catch (err) {
        return next(err);
    }
}


// js date to string "2023-08-07"
function yyyymmdd(date) {
    var mm = date.getMonth() + 1; // getMonth() is zero-based
    var dd = date.getDate();

    return [date.getFullYear(),
    (mm > 9 ? '' : '0') + mm,
    (dd > 9 ? '' : '0') + dd
    ].join('-');
};

export async function checkSheduleIsIn(req, res, next) {
    try {
        const context = {};
        context.CUST_CODE = req.body.cus_code;
        context.SPO_CODE = req.body.spo_code;
        context.SCHEDULE_DT = req.body.date;
        context.dateString = yyyymmdd(req.body.date);

        const status = await checkSheduleIsInTable(context);

        res.status(200).json({
            status
        });

    } catch (err) {
        return next(err);
    }
}



// insert schedule for create scheduule page
export async function insertShedule(req, res, next) {
    try {
        const context = req.body;
        await insertSheduleIntoTable(context);

        res.status(200).json({
            status: 'success',
        });

    } catch (err) {
        console.error(err);
        return next(err);
    }
}



export async function getSheduleByEmployeeDate(req, res, next) {
    try {

        const context = {};
        context.employeeNumber = req.body.employeeNumber;
        context.startDate = req.body.startDate;
        context.endDate = req.body.endDate;
        context.scheduleStatus = req.body.scheduleStatus;
        context.customer = req.body.customer;

        const sheduleList = await getSheduleListByEmployeeDate(context);
        // console.log(sheduleList);

        res.status(200).json({
            status: 'success',
            data: sheduleList,
        });

    } catch (err) {
        return next(err);
    }
}



// list of current date approved, complete and canceled by so schedule for visit schedule page
// export async function getCurrDateShedule(req, res, next) {
//     try {
//         const context = {};
//         context.employeeNumber = req.body.employeeNumber;
//         context.date = req.body.date;
//         // console.log(date);


//         const sheduleList = await getCurrDateSheduleEmployee(context);

//         res.status(200).json({
//             status: 'success',
//             data: sheduleList,
//         });

//     } catch (err) {
//         return next(err);
//     }
// }




// list of current date approved, complete and canceled by so schedule for visit schedule page
export async function getCurrMonthShedule(req, res, next) {
    try {
        const context = {};
        context.employeeNumber = req.body.employeeNumber;
        context.date = req.body.date;
        // console.log(date);

        const sheduleList = await getCurrMonthSheduleEmployee(context); //per month

        res.status(200).json({
            status: 'success',
            data: sheduleList,
        });

    } catch (err) {
        return next(err);
    }
}



// update schedule > APPROVE to CANCEL
export async function updateSheduleCancel(req, res, next) {
    try {
        const context = {};
        context.SCHDL_ID = req.body.SCHDL_ID;
        context.reason = req.body.reason;
        context.employeeNumber = req.body.employeeNumber;

        const result = await updateSheduleStatusCancel(context);

        if (result) {
            res.status(200).json({
                status: 'success'
            });
        }

    } catch (err) {
        return next(err);
    }
}



// update schedule > APPROVE to COMPLETE
export async function updateSheduleComplete(req, res, next) {
    try {
        const context = {};
        context.SCHDL_ID = req.body.SCHDL_ID;
        context.employeeNumber = req.body.employeeNumber;

        const result = await updateSheduleStatusComplete(context);

        if (result) {
            res.status(200).json({
                status: 'success'
            });
        }

    } catch (err) {
        return next(err);
    }
}


// get Shedule Count 3
export async function getSheduleCount(req, res, next) {
    try {
        const context = {};
        context.employee_number = req.body.employee_number;
        const sheduleCount = await getSheduleCountOfCurrentMonth(context);
        console.log(sheduleCount);

        res.status(200).json({
            status: 'success',
            data: sheduleCount,
        });

    } catch (err) {
        return next(err);
    }
}