import dotenv from 'dotenv';
dotenv.config();

import bcrypt from 'bcryptjs';
import jwt from 'jsonwebtoken';

import { promisify } from 'util';

import {
  createMobileAppUser,
  registerMobileAppUser,
  findMobileAppUser,
  getOneEmployee,
  updatePassword,
  policyStatus,
  approvUser,
  updateUser,
  getModuleList,
  meetingInfo,
  getScreenList,
  getMeetingparticipant,
} from '../db_apis/mobile.users.js';

import { generateNewOtp } from '../utils/generateNewOtp.js';
import { FAILED, NOT_FOUND, SUCCESS, UNAUTHORIZED } from '../utils/status.js';
import { verifyOtp } from '../utils/verifyOtp.js';
import { log } from 'console';
import axios from 'axios';


let hash; // save generated hash


// generate OTP and send it to user
// export async function generateOtp(req, res, next) {
//   try {
//     const context = {};
//     context.employee_number = req.body.employee_number;

//     const salesEmployee = await getOneSalesEmployee(context);
//     const empPhone = salesEmployee ? salesEmployee.phone : '';

//     if (empPhone) {
//       hash = generateNewOtp(empPhone);
//       return res
//         .status(200)
//         .json({ status: SUCCESS, hash: hash, phone: empPhone });
//     }
//     return res.status(401).json({
//       status: UNAUTHORIZED,
//       message: 'You are not authorized for NPOLY Sales.',
//     });
//   } catch (error) {
//     return next(error);
//   }
// }
export async function generateOtp(req, res, next) {
  try {
    const context = {};
    context.employee_number = req.body.employee_number;

    const salesEmployee = await getOneEmployee(context);
   
    const empPhone = salesEmployee ? salesEmployee.PHONE : '';
    //const empPhone = '01755512020';
    if (empPhone) {
    //if (salesEmployee) {
      //const empPhone = '01755512020';
     const  hash = await generateNewOtp(empPhone);
      return res
        .status(200)
        .json({ status: SUCCESS, hash: hash, phone: empPhone });
    }
    return res.status(401).json({
      status: UNAUTHORIZED,
      message: 'You are not authorized for NPOLY Off App.',
    });
  } catch (error) {
    return next(error);
  }
}
export async function verifyUserOtp(req, res, next) {
  try {
    const context = {};
    context.phone = req.body.phone;
    context.otp = req.body.otp;
    context.hash = req.body.hash;

    const verifyResult = verifyOtp(context);

    return res.json({ status: verifyResult });
  } catch (error) {
    return next(error);
  }
}

export async function setPassword(req, res, next) {
  try {
    const context = {};
    context.employee_number = req.body.employee_number;
    context.password = req.body.password;
  
    const salt = await bcrypt.genSalt(10);
    const hashedPassword = await bcrypt.hash(context.password, salt);

    const salesEmp = await getOneEmployee(context);
    if (!salesEmp) {
      return res.status(401).json({
        status: UNAUTHORIZED,
        message: 'You are not authorized for Off App.',
      });
    } else if (salesEmp.EMPLOYEENUMBER) {
      const isEmployeeRegistered = await findMobileAppUser(context);

      if (!isEmployeeRegistered) {
        context.employee_number = salesEmp.EMPLOYEENUMBER;
        context.employee_name = salesEmp.EMPLOYEENAME;
        context.password_hash = hashedPassword;
        const user = await createMobileAppUser(context);
        const user_register = await registerMobileAppUser(context);
        // create employee request info in users table start here
        //axios.post('http://192.168.250.17/npoly-ticketing-system/api/userRegister', {
        axios.post('http://192.168.100.34/npoly-ticketing-system/api/userRegister', {
                employeeNumber: salesEmp.EMPLOYEENUMBER,
                employeeName: salesEmp.EMPLOYEENAME,
                designation: salesEmp.DESIGNATION,
                department: salesEmp.DEPARTMENT,
                org_id: salesEmp.ORG_ID,
                loaction: salesEmp.LOACTION,
                religion: salesEmp.RELIGION,
                cardNo: salesEmp.OFFICE_ID?salesEmp.OFFICE_ID:"N/A",
                email: salesEmp.EMAIL?salesEmp.EMAIL:'npoly@nationalpolymer.net',
                bloodGroup: salesEmp.BLOOD_GROUP?salesEmp.BLOOD_GROUP:"N/A",
                mobile: salesEmp.PHONE_NO?salesEmp.PHONE_NO:"01",
                password: req.body.password,
              })
              .then(function (response) {
                return res.status(200).json({
                  status: SUCCESS,
                });
              })
              .catch(function (error) {
                console.log(error);
              });
        // create employee request info in users table end here
        return user
          ? res.status(200).json({
              status: SUCCESS,
              message: 'You are successfully registered.',
            })
          : res.status(401).json({
              status: FAILED,
              message: 'Your registration has been failed. Please try again.',
            });
      } else {
        context.employee_number = salesEmp.EMPLOYEENUMBER;
        context.employee_name = salesEmp.EMPLOYEENAME;
        //context.employee_number = 6586;
        //context.employee_name = 'Md. Azam Ali';
        context.password_hash = hashedPassword;
        const result = await updatePassword(context);
        return result
          ? res.status(201).json({
              status: SUCCESS,
              message: 'You password has been successfully changed.',
            })
          : res.status(401).json({
              status: FAILED,
              message:
                'Your password change has been failed. Please try again.',
            });
      }
    }
  } catch (err) {
    return next(err);
  }
}

export async function login(req, res, next) {
  try {
    const context = {};
    context.employee_number = req.body.employee_number;
    context.password = req.body.password;
    context.version = req.body.version;
    const appVersion = req.body.version =='1.0.0' ?'1.0.0':'2.0.0';

    //if(context.version !== '1.0.0' || context.version === '' || context.version === null){
    if(context.version !== appVersion || context.version === '' || context.version === null){
      return res
          .status(402)
          .json({ status: 'version_law', message: "Sorry you don't have updated version. Please contact with Npoly" });
    }else {

    const salesEmp = await getOneEmployee(context);
    //const salesEmp = true;

    if (salesEmp === null || salesEmp.length > 1) {
      return res.status(401).json({
        status: UNAUTHORIZED,
        message: 'You are not authorized for NPOLY Off Apps.',
      });
    } else {
      
      const isEmployeeRegistered = await findMobileAppUser(context);
      if (isEmployeeRegistered === null) {
        return res
          .status(404)
          .json({ status: NOT_FOUND, message: 'You are not registered yet.' });
      }else if(isEmployeeRegistered.screenStatus === 0){
        return res
          .status(404)
          .json({ status: NOT_FOUND, message: 'You are not approved for login.' });
      } else {
        const isPasswordCorrect = await bcrypt.compare(
          context.password,
          isEmployeeRegistered.password_hash
        );
        if (isPasswordCorrect) {
          const token = jwt.sign(
            { id: context.employee_number,org_id:salesEmp.orgId },
            process.env.JWT_SECRET_KEY,
            { expiresIn: process.env.JWT_EXPIRES_IN }
          );

            // get login info start here
            // var config = {
            //   method: 'post',
            //   url: 'http://192.168.250.17/npoly-ticketing-system/api/getUserInfo',
            //   headers: {
            //     'Content-Type': 'application/json'
            //   },
            //  // data: data
            // };
          
            // axios(config)
            //   .then(function (response) {
            //     console.log(JSON.stringify(response.data));
            //   })
            //   .catch(function (error) {
            //     console.log(error);
            //   });

              // axios.get('http://192.168.250.17/npoly-ticketing-system/api/getModuleScreen')
              // .then(response => {
              //    // console.log(response.data);
              //     return res.status(200).json({
              //       status: SUCCESS,
              //       user_data:response.data,
              //       data: {
              //         employeeNumber: isEmployeeRegistered.employee_number,
              //         employeeName: isEmployeeRegistered.employee_name,
              //         phone: '01558938808',
              //         designation: 'Executive',
              //         officeIdCard: 'NHI-04-011',
              //         screenStatus: '1',
              //         token,
              //       },
              //     });
              // })
              // .catch(error => {
              //     console.error('Error fetching data:', error);
              // });

              //axios.post('http://192.168.250.17/npoly-ticketing-system/api/getModuleScreenByUser', {
              axios.post('http://192.168.100.34/npoly-ticketing-system/api/getModuleScreenByUser', {
                employeeNumber: req.body.employee_number,
              })
              .then(function (response) {
                const user_id = response.data.userId
                //console.log('user_id',response.data.userId)
                return res.status(200).json({
                  status: SUCCESS,
                  screen_info:response.data,
                  stack:response.stack,
                  data: {
                    employeeNumber: isEmployeeRegistered.employee_number,
                    employeeName: isEmployeeRegistered.employee_name,
                    phone: '01558938808',
                    //userId: isEmployeeRegistered.userId,
                    userId: user_id,
                    designationId: isEmployeeRegistered.designationId,
                    departmentId: isEmployeeRegistered.departmentId,
                    isAdmin: isEmployeeRegistered.isAdmin,
                    email: isEmployeeRegistered.email,
                    supportUserId: isEmployeeRegistered.supportUserId,
                    userGrpId: isEmployeeRegistered.userGrpId,
                    userLevelId: isEmployeeRegistered.userLevelId,
                    officeIdCard: '',
                    screenStatus: '1',
                    policyStatus: isEmployeeRegistered.policyStatus,
                    token,
                  },
                });
              })
              .catch(function (error) {
                console.log(error);
              });
              

              // get mobile screen name 
             /* const screenInfo = [];
              if(isEmployeeRegistered.userGrpId && isEmployeeRegistered.userLevelId){
                context.user_group = isEmployeeRegistered.userGrpId;
                context.user_level_id = isEmployeeRegistered.userLevelId;
                const result = await getModuleList(context);
                const screen_info = await Promise.all(result.map(async (module) => {
                  const participants = await getScreenList(isEmployeeRegistered.userGrpId,isEmployeeRegistered.userLevelId,module.MODULE_ID);
                  return {
                      ...module,
                      stack:participants
                  };
              }));
              screenInfo.push(...screen_info);
              }*/

              // return res.status(200).json({
              //   status: SUCCESS,
              //   user_data:screenInfo,
              //   data: {
              //     employeeNumber: isEmployeeRegistered.employee_number,
              //     employeeName: isEmployeeRegistered.employee_name,
              //     phone: '01558938808',
              //     userId: isEmployeeRegistered.userId,
              //     designationId: isEmployeeRegistered.designationId,
              //     departmentId: isEmployeeRegistered.departmentId,
              //     isAdmin: isEmployeeRegistered.isAdmin,
              //     email: isEmployeeRegistered.email,
              //     supportUserId: isEmployeeRegistered.supportUserId,
              //     userGrpId: isEmployeeRegistered.userGrpId,
              //     userLevelId: isEmployeeRegistered.userLevelId,
              //     officeIdCard: '',
              //     screenStatus: '1',
              //     policyStatus: isEmployeeRegistered.policyStatus,
              //     token,
              //   },
              // });

              

              // axios.post('http://192.168.250.17/npoly-ticketing-system/api/getModuleScreenByUser', {
              //   employeeNumber: req.body.employee_number,
              // })
              // .then(function (response) {
              //   return res.status(200).json({
              //     status: SUCCESS,
              //     user_data:response.data,
              //     data: {
              //       employeeNumber: isEmployeeRegistered.employee_number,
              //       employeeName: isEmployeeRegistered.employee_name,
              //       phone: '01558938808',
              //       userId: isEmployeeRegistered.userId,
              //       designationId: isEmployeeRegistered.designationId,
              //       departmentId: isEmployeeRegistered.departmentId,
              //       isAdmin: isEmployeeRegistered.isAdmin,
              //       email: isEmployeeRegistered.email,
              //       supportUserId: isEmployeeRegistered.supportUserId,
              //       userGrpId: isEmployeeRegistered.userGrpId,
              //       userLevelId: isEmployeeRegistered.userLevelId,
              //       officeIdCard: '',
              //       screenStatus: '1',
              //       policyStatus: isEmployeeRegistered.policyStatus,
              //       token,
              //     },
              //   });
              // })
              // .catch(function (error) {
              //   console.log(error);
              // });
          
            // get login info end here

            // const allowedScreens= [
            //   'HomeScreen',
            //   'TicketScreen',
            //   'Stack12',
            //   //'Stack34',
            // ]

            const allowedScreens=  [
             
              {
                drawer: 'TicketScreen',
                stack: [],
              },
              {
                drawer: 'Stack12',
                stack: ['Screen1', 'Screen2', 'Screen3', 'Screen4'],
              },
              // {
              //   drawer: 'Stack34',
              //   stack: ['Screen3', 'Screen4'],
              // },
            ];


          // return res.status(200).json({
          //   status: SUCCESS,
          //   data: {
          //     employeeNumber: 6586,
          //     employeeName: 'Md. Azam Ali',
          //     phone: '01558938808',
          //     designation: 'Executive',
          //     officeIdCard: 'NHI-04-011',
          //     screenStatus: '1',
          //     screen: allowedScreens,
          //     token,
          //   },
          // });

        } else {
          return res
            .status(401)
            .json({ status: UNAUTHORIZED, message: 'Wrong Password' });
        }
      }
    }
  }
  } catch (err) {
    return next(err);
  }
}

// auth protection middleware
export async function authProtection(req, res, next) {
  // 1) Getting token and check of it's there
  let token;
  if (
    req.headers.authorization &&
    req.headers.authorization.startsWith('Bearer')
  ) {
    token = req.headers.authorization.split(' ')[1];
  }

  if (!token || token === '' || token === 'null' || token === 'undefined') {
    return res
      .status(401)
      .json({ status: FAILED, message: 'You are not authorized!' });
  }

  // 2) Verification token
  const decoded = await promisify(jwt.verify)(
    token,
    process.env.JWT_SECRET_KEY
  );

  // 3) Check if user still exists
  const context = {};
  context.employee_number = decoded.id;
  const currentUser = await findMobileAppUser(context);

  if (!currentUser) {
    return res
      .status(401)
      .json({ status: FAILED, message: 'You are not authorized!' });
  }
  //req.userId = decoded.id;
  req.orgId = decoded.org_id;

  next();
}

export async function changePolicyStatus(req, res, next) {
  try {
    const context = {};
    context.employee_number = parseInt(req.body.employee_number);

    const result = await policyStatus(context);

    return result !== null
    ? res.json({ status: SUCCESS, result })
    : res
        .status(404)
        .json({ status: FAILED, message: 'Policy Status not updated' });
} catch (error) {
  return next(error);
}
}
export async function approveMobleUser(req, res, next) {
  try {
    const context = {};
    context.employee_number = parseInt(req.params.userId);
    context.active_status = parseInt(req.params.activeStatus);

    const result = await approvUser(context);

    // context.employee_number = parseInt(req.params.userId);
    // context.user_grp = parseInt(req.params.userGrpId);
    // context.user_lvl = parseInt(req.params.userLvlId);

    const employee_number = parseInt(req.params.userId);
    const user_grp = parseInt(req.params.userGrpId);
    const user_lvl = parseInt(req.params.userLvlId);


    //const updateusers = await updateUser(context);
    const updateusers = await updateUser(employee_number,user_grp,user_lvl);

    return result !== null
    ? res.json({ status: SUCCESS, result })
    : res
        .status(404)
        .json({ status: FAILED, message: 'Policy Status not updated' });
} catch (error) {
  return next(error);
}
}


export async function meetingCheck(req, res, next) {
  try {
    const context = {};
    context.employee_number = parseInt(req.body.employee_number);

    const result = await meetingInfo(context);
    const meeting_info = await Promise.all(result.map(async (meeting) => {
      const participants = await getMeetingparticipant(meeting.MEETING_ID);
      return {
          ...meeting,
          MEETING_PARTICIPANT:participants
      };
  }));
    
    return meeting_info
    ? res.status(200).json({ len: meeting_info.length, data: meeting_info })
    : res.status(404).json({ len: 0, data: [] });
} catch (error) {
  next(error);
}
}




