//shadi
import OracleDB from 'oracledb';

import { simpleExecute } from '../services/database.js';

const status = {
    SUBMIT: "SUBMIT",   //sp submitted
    APPROVE: "APPROVE", //ho approved
    REJECT: "REJECT",   //ho rejected
    COMPLETE: "COMPLETE", //sp completed
    CANCEL: "CANCEL"    //sp canceled
}


export async function getCustomerListByEmployeeNumber(context) {
    try {
        let query = `SELECT CUSTOMER_ID,ACCOUNT_NAME FROM APPS.XX_CUSTOMER_SHIPPING_DETAILS@SALES
        WHERE SALESREP_NUMBER = :employee_code
        AND CUSTOMER_ID NOT IN(
            SELECT CUST_CODE FROM XX_CUSTOMER_INFO
            WHERE APV_FLG = 'Y'
            OR  APV_FLG = 'N'
        )`;

        const binds = {};
        binds.employee_code = context.employee_number;

        const result = await simpleExecute(query, binds);

        return result.rows.length === 0 ? 0 : result.rows;
    }
    catch (err) {
        console.error('Catched Error For getCustomerListByEmployeeNumber():', err);
    }
}


export async function getCustomerInfoByCustomerId(context) {
    try {
        let query = `SELECT
    S.CUSTOMER_ID,
    S.ACCOUNT_NAME,
    S.CUSTOMER_PHONE_NO,
    S.ADDRESS1,
    S.ADRESS5,
    S.ORG_ID,
    (
        SELECT ORGANIZATION_NAME FROM apps.ORG_ORGANIZATION_DEFINITIONS@SALES
        WHERE ORGANIZATION_ID=S.ORG_ID
    )ORG_NAME,
    S.SALESREP_NUMBER,
    C.ZONE_ID,
    C.ZONE,
    C.BASE,
    C.DIV_ID,
    C.DIVISION
    FROM APPS.XX_CUSTOMER_SHIPPING_DETAILS@SALES S,apps.XX_CUSTTERRSRZMDM_V@SALES C`

        const binds = {};

        if (context.employee_number && context.customer_id) {
            binds.customer_id = context.customer_id;
            binds.employee_number = context.employee_number;

            query += `\nWHERE S.CUSTOMER_ID=C.CUSTOMER_ID`;
            query += `\nAND S.CUSTOMER_ID = :customer_id`;
            query += `\nAND S.COMBINATION_ID=C.COMBINATION_ID`;
            query += `\nAND S.SALESREP_NUMBER = :employee_number`;
        }

        const result = await simpleExecute(query, binds);

        return result.rows.length === 0 ? 0 : result.rows;
    }
    catch (err) {
        console.error('Catched Error For getCustomerInfoByCustomerId():', err);
    }
}



export async function checkCustomerIsInTable(CUST_CODE) {
    try {
        let query = `SELECT CUST_CODE FROM xx_customer_info 
    WHERE CUST_CODE = ${CUST_CODE}
    AND APV_FLG = 'N'`
        const binds = {};
        const result = await simpleExecute(query, binds);
        return result.rows.length === 0 ? false : true;
    }
    catch (err) {
        console.error('Catched Error For checkCustomerIsInTable():', err);
    }
}

// insert
export async function insertOneCustomerIntoTable(context) {
    try {
        const { CUST_CODE, CUST_NAME, CUST_MOB_NO, ADDRESS1, ADDRESS2, BASE, DIV_ID, DIVISION, ZONE_ID, ZONE, MKT_HOLYDAY, ORG_ID, ORG_NAME, SPO_CODE, AC_LATITUDE, AC_LONGITUDE, CREATED_BY, CREATED_BY_NAME, IMAGE } = context;

        let query = `INSERT INTO XX_CUSTOMER_INFO (
        CUST_CODE, 
        CUST_NAME, 
        CUST_MOB_NO, 
        ADDRESS1, 
        ADDRESS2, 
        BASE, 
        DIV_ID, 
        DIVISION, 
        ZONE_ID, 
        ZONE, 
        MKT_HOLYDAY, 
        ORG_ID, 
        ORG_NAME, 
        SPO_CODE, 
        AC_LATITUDE, 
        AC_LONGITUDE, 
        CREATED_BY, 
        CREATED_BY_NAME, 
        IMAGE_URL
    )
    VALUES (
        ${CUST_CODE}, 
        '${CUST_NAME}', 
        '${CUST_MOB_NO}', 
        '${ADDRESS1}', 
        '${ADDRESS2}', 
        '${BASE}', 
        ${DIV_ID}, 
        '${DIVISION}', 
        ${ZONE_ID}, 
        '${ZONE}', 
        '${MKT_HOLYDAY}', 
        ${ORG_ID}, 
        '${ORG_NAME}', 
        ${SPO_CODE}, 
        '${AC_LATITUDE}', 
        '${AC_LONGITUDE}', 
        ${CREATED_BY}, 
        '${CREATED_BY_NAME}',
        '${IMAGE}' 
    )`

        const binds = {};

        const result = await simpleExecute(query, binds);

        return result && result.rowsAffected === 1 ? true : false;
    }
    catch (err) {
        console.error('Catched Error For insertOneCustomerIntoTable():', err);
    }
}



// list of available customer list which do not have schedule  by date for create schedule page 
export async function getApprovedAvailableCustomerListByEmployeeNumber(context) {
    try {
        let query = `select CUST_CODE, CUST_NAME 
        from XX_CUSTOMER_INFO
        where APV_FLG = 'Y'
        and SPO_CODE = :employee_number
        and CUST_CODE not in (
            select CUST_CODE
            from XX_MS_SCHEDULE_CHD
            where SPO_CODE = :employee_number
            and  TRUNC(SCHEDULE_DT)= TRUNC(:selected_date)
            and STATUS in ( '${status.SUBMIT}', '${status.APPROVE}', '${status.COMPLETE}' )
        )`;

        const binds = {};
        if (context.employee_number && context.selected_date) {
            binds.employee_number = context.employee_number;
            binds.selected_date = context.selected_date;
        }

        // console.log(query);

        const result = await simpleExecute(query, binds);
        return result.rows.length === 0 ? 0 : result.rows;
    }
    catch (err) {
        console.error('Catched Error For getApprovedAvailableCustomerListByEmployeeNumber():', err);
    }
}



// list of approved customer by so
export async function getApprovedCustomerListByEmployeeNumber(context) {
    try {
        console.log(context);
        let query = `SELECT CUST_CODE, CUST_NAME
        FROM XX_CUSTOMER_INFO
        WHERE APV_FLG = 'Y'`;

        const binds = {};
        if (context.employee_number) {
            binds.employee_number = context.employee_number;
            query += `\nAND SPO_CODE = :employee_number`;
        }

        const result = await simpleExecute(query, binds);
        return result.rows.length === 0 ? 0 : result.rows;
    }
    catch (err) {
        console.error('Catched Error For getApprovedCustomerListByEmployeeNumber():', err);
    }
}



export async function getApprovedCustomerInfoByCustomerId(context) {
    try {
        let query = `SELECT CUST_NAME, 
            ORG_ID, 
            ORG_NAME, 
            ADDRESS1, 
            ADDRESS2,
            AC_LATITUDE, 
            AC_LONGITUDE, 
            MIN_DISRNGE
        FROM XX_CUSTOMER_INFO`;

        const binds = {};

        if (context.employee_number && context.customer_id) {
            binds.customer_id = context.customer_id;
            binds.employee_number = context.employee_number;

            query += `\nWHERE CUST_CODE= :customer_id`;
            query += `\nAND SPO_CODE = :employee_number`;
        }

        const result = await simpleExecute(query, binds);
        return result.rows.length === 0 ? 0 : result.rows;
    }
    catch (err) {
        console.error('Catched Error For getApprovedCustomerInfoByCustomerId():', err);
    }
}



export async function checkSheduleIsInTable(context) {
    try {
        const { CUST_CODE, SPO_CODE, SCHEDULE_DT, dateString } = context;

        let query = `SELECT SCHEDULE_DT 
        FROM XX_MS_SCHEDULE_CHD`;

        const binds = {};

        if (CUST_CODE && SCHEDULE_DT && dateString) {
            binds.CUST_CODE = CUST_CODE;
            binds.SPO_CODE = SPO_CODE;
            binds.SCHEDULE_DT_String = dateString;

            query += `\nWHERE CUST_CODE= :CUST_CODE`;
            query += `\nAND SPO_CODE = :SPO_CODE`;
            query += `\nAND TO_CHAR(SCHEDULE_DT, 'YYYY-MM-DD') = :SCHEDULE_DT_String`;
        }

        const result = await simpleExecute(query, binds);

        return result.rows.length === 0 ? false : true;
    }
    catch (err) {
        console.error('Catched Error For checkSheduleIsInTable():', err);
    }
}




// insert multiple schedule for create scheduule page
export async function insertSheduleIntoTable(context) {
    try {
        let query = `DECLARE
        CURSOR CUR_INS
        IS
            SELECT ORG_ID, AC_LATITUDE, AC_LONGITUDE, MIN_DISRNGE
            FROM XX_CUSTOMER_INFO
            WHERE CUST_CODE = :CUST_CODE 
            AND SPO_CODE = :SPO_CODE
            AND APV_FLG = 'Y';
        BEGIN
        FOR I IN CUR_INS
        LOOP
            INSERT INTO XX_MS_SCHEDULE_CHD 
            (ORG_ID, AC_LATITUDE, AC_LONGITUDE, MIN_DISRNGE, STATUS, CUST_CODE, SPO_CODE, CREATED_BY, SCHEDULE_DT)
            VALUES (I.ORG_ID, I.AC_LATITUDE, I.AC_LONGITUDE, I.MIN_DISRNGE, 'SUBMIT', :CUST_CODE, :SPO_CODE, :SPO_CODE, :SCHEDULE_DT);
        END LOOP;
        END;`

        //loop each element of array to insert
        context.forEach(async (item) => {
            const binds = {};
            binds.CUST_CODE = item.CUST_CODE;
            binds.SPO_CODE = item.SPO_CODE;
            binds.SCHEDULE_DT = item.SCHEDULE_DT;
            // console.log(query);
            await simpleExecute(query, binds);
        });
    }
    catch (err) {
        console.error('Catched Error For insertSheduleIntoTable():', err);
    }
}



export async function getSheduleListByEmployeeDate(context) {
    try {
        console.log(context);
        let query = `SELECT c.CUST_CODE, 
            c.CUST_NAME, 
            c.ADDRESS1, 
            c.ADDRESS2, 
            s.SCHEDULE_DT, 
            s.STATUS
        FROM XX_CUSTOMER_INFO c, XX_MS_SCHEDULE_CHD s
        WHERE c.CUST_CODE = s.CUST_CODE
        AND c.APV_FLG = 'Y'`;



        const binds = {};
        if (context) {
            binds.employeeNumber = context.employeeNumber;
            binds.startDate = context.startDate;
            binds.endDate = context.endDate;
            binds.scheduleStatus = context.scheduleStatus;

            // binds.offset = context.offset;
            query += `\nAND s.STATUS  = :scheduleStatus`;
            query += `\nAND s.SPO_CODE = :employeeNumber`;
            if (context.customer != null) {
                binds.customerCode = context.customer.CUST_CODE;
                query += `\nAND s.CUST_CODE= :customerCode`;
            }
            query += `\nAND TRUNC(s.SCHEDULE_DT) BETWEEN TRUNC(:startDate) AND TRUNC(:endDate)`;
            query += `\nORDER BY s.SCHEDULE_DT`;
            // query += `\nOFFSET :offset ROWS FETCH NEXT 10 ROWS ONLY`;
        }

        const result = await simpleExecute(query, binds);

        return result.rows.length === 0 ? 0 : result.rows;
    }
    catch (err) {
        console.error('Catched Error For getSheduleListByEmployeeDate():', err);
    }
}






// list of current date approved, complete and canceled by so schedule for visit schedule page
// export async function getCurrDateSheduleEmployee(context) {
//     try {
//         console.log('context', context);
//         let query = `SELECT  s.CUST_CODE,
//             (select CUST_NAME from XX_CUSTOMER_INFO where CUST_CODE=s.CUST_CODE AND APV_FLG = 'Y') as CUST_NAME, 
//             (select ADDRESS1 from XX_CUSTOMER_INFO where CUST_CODE=s.CUST_CODE AND APV_FLG = 'Y') as ADDRESS1, 
//             (select ADDRESS2 from XX_CUSTOMER_INFO where CUST_CODE=s.CUST_CODE AND APV_FLG = 'Y') as ADDRESS2,
//             s.AC_LATITUDE, 
//             s.AC_LONGITUDE,
//             s.SCHDL_ID,
//             s.STATUS,
//             s.SCHEDULE_DT
//         FROM XX_MS_SCHEDULE_CHD s
//         WHERE s.STATUS != '${status.SUBMIT}' 
//         AND s.STATUS != '${status.REJECT}'`;



//         const binds = {};
//         if (context.employeeNumber && context.date) {
//             binds.employeeNumber = context.employeeNumber;
//             binds.currentDate = context.date;
//             query += `\nAND s.SPO_CODE = :employeeNumber`;
//             query += `\nAND TRUNC(s.SCHEDULE_DT)= TRUNC(:currentDate)`;
//         }
//         console.log(query);

//         const result = await simpleExecute(query, binds);
//         console.log(result);

//         return result.rows.length === 0 ? [] : result.rows;
//     }
//     catch (err) {
//         console.error('Catched Error For getCurrDateSheduleEmployee():', err);
//     }
// }



// list of current date approved, complete and canceled by so schedule for visit schedule page per month
export async function getCurrMonthSheduleEmployee(context) {
    try {
        console.log('context', context);
        let query = `SELECT  s.CUST_CODE,
            (select CUST_NAME from XX_CUSTOMER_INFO where CUST_CODE=s.CUST_CODE AND APV_FLG = 'Y') as CUST_NAME, 
            (select ADDRESS1 from XX_CUSTOMER_INFO where CUST_CODE=s.CUST_CODE AND APV_FLG = 'Y') as ADDRESS1, 
            (select ADDRESS2 from XX_CUSTOMER_INFO where CUST_CODE=s.CUST_CODE AND APV_FLG = 'Y') as ADDRESS2,
            s.AC_LATITUDE, 
            s.AC_LONGITUDE,
            s.SCHDL_ID,
            s.STATUS,
            s.SCHEDULE_DT
        FROM XX_MS_SCHEDULE_CHD s
        WHERE s.STATUS != '${status.SUBMIT}'
        AND s.STATUS != '${status.REJECT}'`;

        const binds = {};
        if (context.employeeNumber && context.date) {
            binds.employeeNumber = context.employeeNumber;
            binds.currentDate = context.date;
            query += `\n AND s.SPO_CODE = :employeeNumber`;
            query += `\n AND TRUNC(SCHEDULE_DT) between TRUNC(:currentDate,'month') and CASE
            WHEN to_char(sysdate, 'Month') = to_char(:currentDate, 'Month') THEN TRUNC(:currentDate)
            ELSE TRUNC(last_day(:currentDate))
            END`;
            query += `\n ORDER BY SCHEDULE_DT`;
        }
        console.log(query);

        const result = await simpleExecute(query, binds);
        console.log(result);

        return result.rows.length === 0 ? [] : result.rows;
    }
    catch (err) {
        console.error('Catched Error For getCurrMonthSheduleEmployee():', err);
    }
}



// update schedule > APPROVE to CANCEL
export async function updateSheduleStatusCancel(context) {
    try {
        let query = `UPDATE XX_MS_SCHEDULE_CHD
        SET STATUS = '${status.CANCEL}', 
            CANCEL_REASON = :reason, 
            CANCEL_DATE = sysdate, 
            CANCEL_BY = :employeeNumber
        WHERE SCHDL_ID = :SCHDL_ID`;

        // console.log('context', context);
        const binds = context;

        const result = await simpleExecute(query, binds);

        return result && result.rowsAffected === 1 ? true : false;
    }
    catch (err) {
        console.error('Catched Error For updateSheduleStatusCancel():', err);
    }
}



// update schedule > APPROVE to COMPLETE
export async function updateSheduleStatusComplete(context) {
    try {
        let query = `UPDATE XX_MS_SCHEDULE_CHD
        SET STATUS = '${status.COMPLETE}', 
            COMPLETE_DATE = sysdate, 
            COMPLETE_BY = :employeeNumber
        WHERE SCHDL_ID = :SCHDL_ID`;

        // console.log('context', context);
        const binds = context;

        const result = await simpleExecute(query, binds);

        return result && result.rowsAffected === 1 ? true : false;
    }
    catch (err) {
        console.error('Catched Error For updateSheduleStatusComplete():', err);
    }
}



//getSheduleCount
export async function getSheduleCountOfCurrentMonth(context) {
    try {
        let query = `SELECT 
            trunc(SCHEDULE_DT) as SCHEDULE_DT,
            count(CASE when STATUS = 'SUBMIT' then 1 END) as  SUBMITTED,
            count(CASE when STATUS = 'APPROVE' then 1 END) as  APPROVED,
            count(CASE when STATUS = 'COMPLETE' then 1 END) as  COMPLETED,
            count(CASE when STATUS = 'CANCEL' or STATUS = 'REJECT'  THEN 1 END) as  CANCELED
        FROM XX_MS_SCHEDULE_CHD 
        where SPO_CODE = :employee_number
        and TRUNC(SCHEDULE_DT) between TRUNC(sysdate,'month') and TRUNC(last_day(sysdate))
        GROUP BY TRUNC(SCHEDULE_DT)
        ORDER BY SCHEDULE_DT`;


        const binds = {};
        if (context.employee_number) {
            binds.employee_number = context.employee_number;
        }
        const result = await simpleExecute(query, binds);

        // return result.rows.length === 0 ?
        //     [{ SCHEDULE_DT: new Date(), SUBMITTED: 0, APPROVED: 0, COMPLETED: 0, CANCELED: 0 }]
        //     : result.rows;

        return result.rows.length === 0 ? 0 : result.rows;
    }
    catch (err) {
        console.error('Catched Error For getSheduleCountOfCurrentMonth():', err);
    }
}


