import OracleDB from 'oracledb';

import { simpleExecute } from '../services/database.js';

const baseOrderHeaderQuery = `SELECT 
        n.NOTIFICATION_ID "notificationId",
        n.EMPLOYEE_NUMBER "employeeNumber",
        n.CUSTOMER_NUMBER "customerNumber",
        n.CUSTOMER_NAME "customerName",
        n.ADDRESS "address",
        n.PRODUCT_TYPE "productType",
        n.ORDER_ID "orderId",
        n.ORDER_STATUS "orderStatus",
        n.ORDER_DATE "orderDate",
        n.MR_ID "mrID",
        n.MR_STATUS "mrStatus",
        n.MR_DATE "mrDate",
        n.NOTIFICATION_DATE "NoticeDate",
        n.VIEWED_STATUS "viewedStatus",
        n.VIEWED_STATUS "status",
        u.USRS_FNAME "viewedBy"
      FROM 
      XX_NOTIFICATION n
      LEFT JOIN NPL_SAUSERS u ON u.SAUSERS_ID = n.VIEWED_BY
      `;

export async function getAllNotification(context) {
  let query = baseOrderHeaderQuery;
  const binds = {};
  
  if (context.created_by) {
    binds.created_by = context.created_by;
   
    query += `\nWHERE n.EMPLOYEE_NUMBER = :created_by`;
    query += `\nORDER BY n.NOTIFICATION_ID DESC`;
    query += `\nFETCH FIRST 50 ROWS ONLY`;
  }

  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? null : result.rows;
}

export const getOneNotification = async (context) => {

  let query = `SELECT 
        n.NOTIFICATION_ID "notificationId",
        n.EMPLOYEE_NUMBER "employeeNumber",
        n.CUSTOMER_NUMBER "customerNumber",
        n.CUSTOMER_NAME "customerName",
        n.ADDRESS "address",
        n.PRODUCT_TYPE "productType",
        n.ORDER_ID "orderId",
        n.ORDER_STATUS "orderStatus",
        n.ORDER_DATE "orderDate",
        n.MR_ID "mrID",
        n.MR_STATUS "mrStatus",
        n.MR_DATE "mrDate",
        n.NOTIFICATION_DATE "NoticeDate",
        n.VIEWED_STATUS "viewedStatus",
        n.VIEWED_STATUS "status",
        u.USRS_FNAME "viewedBy"
      FROM 
      XX_NOTIFICATION n
      LEFT JOIN NPL_SAUSERS u ON u.SAUSERS_ID = n.VIEWED_BY
    `;

  const binds = {};

  if (context.Notification_id) {
    binds.id = context.Notification_id;
    binds.created_by = context.created_by;

    query += `\nWHERE n.NOTIFICATION_ID = :id`;
    query += `\nAND n.EMPLOYEE_NUMBER = :created_by`;
  }

  const result = await simpleExecute(query, binds);
  return result.rows[0];
};


const toValQuery = `SELECT COUNT(*) totNotice FROM XX_NOTIFICATION`;
export async function getTotNotification(context) {
  let query = toValQuery;
  const binds = {};
  
  if (context.created_by) {
    
    binds.created_by = context.created_by;
    query += `\nWHERE EMPLOYEE_NUMBER = :created_by`;
    query += `\nAND VIEWED_STATUS = 0`;
  }

  const result = await simpleExecute(query, binds);
  return result.rows[0];
}