import OracleDB from 'oracledb';

import { simpleExecute } from '../services/database.js';

const baseQuery = `SELECT distinct 
ORACLE_ID employeeNumber,
FULL_NAME employeeName,
DEPARTMENT department,
DESIGNATION designation,
OFFICE_ID cardNo,
BLOOD_GROUP bloodGroup,
PHONE_NO phone,
LOCATION loaction,
ORGANIZATION_ID org_id,
RELIGION religion,
EMAIL email
  FROM SYS.XXNPTICKET_APP_HR_V`;

export async function getSalesEmployees(context) {
  let query = baseQuery;
  const binds = {};

  const result = await simpleExecute(query, binds);

  return result ? result.rows : null;
}

export async function getOneEmployee(context) {
  let query = baseQuery;
  const binds = {};

  if (context.employee_number) {
    binds.employee_code = context.employee_number;
    query += `\nWHERE oracle_id = :employee_code`;
    //query += `\nAND PHONE_NO IS NOT NULL`;
   // query += `\nAND PHONE_NO IS NOT NULL`;
    query += `\nAND ROWNUM = 1`;
  }

  const result = await simpleExecute(query, binds);

  return result && result.rows && result.rows.length === 1
    ? result.rows[0]
    : null;
}

// const userBaseQuery = `SELECT
//     employee_number "employee_number",
//     employee_name "employee_name",
//     password_hash "password_hash",
//     POLICY_STATUS "policyStatus",
//     USER_STATUS "screenStatus"
//   FROM 
//   XX_TKT_OFF_APP_USERS`;
  const userBaseQuery = `SELECT
                            TU.ID "userId",
                            TU.DEPARTMENT_ID "departmentId",
                            TU.DESIGNATION "designationId",
                            TU.IS_ADMIN "isAdmin",
                            TU.EMAIL_ADDRESS "email",
                            TU.SUPPORT_USER_ID "supportUserId",
                            TU.USERGRP_ID "userGrpId",
                            TU.USERLVL_ID "userLevelId",
                            mu.employee_number "employee_number",
                            mu.employee_name "employee_name",
                            mu.password_hash "password_hash",
                            mu.POLICY_STATUS "policyStatus",
                            mu.USER_STATUS "screenStatus"
                          FROM 
                          XX_TKT_OFF_APP_USERS mu,xx_tkt_users tu
                          where MU.EMPLOYEE_NUMBER = TU.EMPLOYEE_NUMBER
                          `;

export async function findMobileAppUser(context) {
  let query = userBaseQuery;
  const binds = {};

  if (context.employee_number) {
    binds.employee_number = context.employee_number;
    query += `\nAND mu.employee_number = :employee_number`;
  }

  const result = await simpleExecute(query, binds);

  return result && result.rows && result.rows.length === 1
    ? result.rows[0]
    : null;
}
export async function meetingInfo(context) {
  let query = `select * from XX_TKT_MEETING_ROOM_BOOKING where trunc(meeting_date) = trunc(sysdate -3)`;
  const binds = {};

  const result = await simpleExecute(query, binds);

  return result.rows.length > 0 ? result.rows : null;
}
export async function getMeetingparticipant(meetingId) {
  let meeting_id = meetingId;
  let query = `SELECT MEETING_ID,PARTICIPANT_ID FROM XX_TKT_MEETING_PARTICIPENT WHERE MEETING_ID = ${meeting_id}`;
  const binds = {};

  const result = await simpleExecute(query, binds);

  return result.rows.length > 0 ? result.rows : null;
}
export async function getModuleList(context) {
  let query = `SELECT DISTINCT SL.MODULE_ID,M.MODULE_NAME AS DRAWER FROM XX_TKT_MOBILE_UGLW_MLINK  SL,XX_TKT_MOBILE_MODULE  M
  WHERE SL.MODULE_ID = M.MODULE_ID`;
  const binds = {};

  if (context.user_group && context.user_level_id) {
    binds.user_group = context.user_group;
    binds.user_level_id = context.user_level_id;

    query += `\nAND USERGRP_ID =:user_group`;
    query += `\nAND UG_LEVEL_ID =:user_level_id`;
    query += `\nAND SL.STATUS=1 ORDER BY SL.MODULE_ID`;
  }

  const result = await simpleExecute(query, binds);

  return result.rows.length > 0 ? result.rows : null;
}
export async function getScreenList(userGrpId,userLevelId,moduleId) {
  let module_id = moduleId;
  let user_group_id = userGrpId;
  let user_level_id = userLevelId;
  let query = `SELECT SL.SCREEN_ID, MS.SCREEN_NAME FROM XX_TKT_MOBILE_UGLW_MLINK  SL,XX_TKT_MOBILE_MODULE_SCREEN  MS
  WHERE SL.SCREEN_ID = MS.SCREEN_ID
  AND USERGRP_ID = ${user_group_id}
  AND UG_LEVEL_ID =${user_level_id}
  AND SL.MODULE_ID =${module_id}
  AND SL.STATUS=1`;
  const binds = {};

  const result = await simpleExecute(query, binds);

  return result.rows.length > 0 ? result.rows : null;
}


const createSql = `insert into XX_TKT_OFF_APP_USERS (
    employee_number,
    employee_name,
    user_status,
    password_hash
  ) values (
    :employee_number,
    :employee_name,
    :user_status,
    :password_hash
  ) returning id
  into :id`;

  const registerSql = `insert into XX_TKT_USERS (
    employee_number,
    name,
    password,
    active_status,
    request_from
  ) values (
    :employee_number,
    :employee_name,
    :password_hash,
    :active_status,
    :request_from
  ) returning id
  into :id`;

export async function createMobileAppUser(context) {
  const employee = {};

  employee.id = {
    dir: OracleDB.BIND_OUT,
    type: OracleDB.NUMBER,
  };

  employee.employee_number = context.employee_number;
  employee.employee_name = context.employee_name;
  employee.user_status = 1;
  employee.password_hash = context.password_hash;

  const result = await simpleExecute(createSql, employee);

  employee.id = result.outBinds.id[0];
  return employee.id ? employee : null;
}
export async function registerMobileAppUser(context) {
  const employee = {};

  employee.id = {
    dir: OracleDB.BIND_OUT,
    type: OracleDB.NUMBER,
  };

  employee.employee_number = context.employee_number;
  employee.employee_name = context.employee_name;
  employee.password_hash = context.password_hash;
  employee.active_status = 1;
  employee.request_from = 1;

  const result = await simpleExecute(registerSql, employee);

  employee.id = result.outBinds.id[0];
  return employee.id ? employee : null;
}


export async function updatePassword(context) {
  let query = `UPDATE XX_TKT_OFF_APP_USERS`;
  const binds = {};

  if (context.employee_number && context.password_hash) {
    binds.employee_number = context.employee_number;
    binds.password_hash = context.password_hash;

    query += `\nSET
        password_hash = :password_hash,
        updated_at = SYSDATE
    WHERE employee_number = :employee_number`;
  }

  const result = await simpleExecute(query, binds);

  return result.rowsAffected === 1 ? true : false;
}

export async function updateMobileUser(context) {
  let query = updateSql;
  const binds = {};

  if (context.employee_number && context.password_hash) {
    binds.employee_number = context.employee_number;
    binds.password_hash = context.password_hash;

    query += `UPDATE XX_TKT_OFF_APP_USERS
    SET
        password_hash = :password_hash,
        updated_at = SYSDATE
    WHERE employee_number = :employee_number`;
  } else if (context.employee_number && context.password_hash) {
    binds.employee_number = context.employee_number;
    binds.password_hash = context.password_hash;
  }

  const result = await simpleExecute(query, binds);

  return result.rowsAffected === 1 ? true : false;
}

export async function sendSmsByProcedure(message,phone) {
  //let query = `begin pos.PROC_SEND_SMS_TEST405_BM('${message}','${phone}'); end;`;
  let query = `begin pos.XX_BL_SMS_BAN_APEX('${phone}','${message}'); end;`;
  const binds = {};

  const result = await simpleExecute(query, binds);
  return result;
}

export async function policyStatus(context) {
  let query = `UPDATE XX_TKT_OFF_APP_USERS`;
  const obj = Object.assign({}, context);

  if (obj.employee_number) {
    query += `\nSET
        POLICY_STATUS = 1
    WHERE
    EMPLOYEE_NUMBER = :employee_number`;
  }

  const result = await simpleExecute(query, obj);
  return result.rowsAffected === 1 ? obj.ma_line_id : null;
}
export async function approvUser(context) {
  let query = `UPDATE XX_TKT_OFF_APP_USERS`;
  const obj = Object.assign({}, context);

  if (obj.employee_number) {
    query += `\nSET
    USER_STATUS = :active_status
    WHERE
    EMPLOYEE_NUMBER = :employee_number`;
  }

  const result = await simpleExecute(query, obj);
  return result.rowsAffected === 1 ? obj.id : null;
}
// export async function updateUser(context) {
//   let query = `UPDATE XX_TKT_USERS`;
//   const obj = Object.assign({}, context);
//   console.log('obj',obj);
//   if (obj.employee_number) {
//     query += `\nSET
//     USERGRP_ID = :user_grp,
//     USERLVL_ID = :user_lvl
//     WHERE
//     EMPLOYEE_NUMBER = :employee_number`;
//   }
  

//   const result = await simpleExecute(query, obj);
//   return result.rowsAffected === 1 ? obj.id : null;
// }
export async function updateUser(employee_number,user_grp,user_lvl) {
  let employeeNumber = employee_number;
  let userGrp = user_grp;
  let userLvl = user_lvl;
  let query = `UPDATE XX_TKT_USERS`;
    query += `\nSET
    USERGRP_ID = ${userGrp},
    USERLVL_ID =  ${userLvl}
    WHERE
    EMPLOYEE_NUMBER = ${employeeNumber}`;
  
  
  const binds = {};
  const result = await simpleExecute(query, binds);
  return result.rowsAffected === 1 ? true : null;
}


