import OracleDB from 'oracledb';

import { simpleExecute } from '../services/database.js';

const specReqOrderHeaderQuery = `SELECT DISTINCT
OL.MA_ORDER_ID "orderId",
OH.CUSTOMER_NAME "customerName",
OH.SUBMISSION_DATE "submissionDate",
OH.PRODUCT_NAME,
OH.CUSTOMER_NUMBER"customerNumber",
OH.ORDER_TYPE_NAME "orderType" ,
OH.STATUS "orderStatus"
FROM XX_MOBILE_ORDER_LINES OL,XX_MOBILE_ORDER_HEADERS OH
WHERE OL.MA_ORDER_ID = OH.MA_ORDER_ID`;

export async function getAllNotification(context) {
  
    let query = specReqOrderHeaderQuery;
  const binds = {};

    query += `\nAND OL.SUGG_FG = 'E'`;
    query += `\nAND OH.STATUS = 'DRAFT'`;
    query += `\nORDER BY OH.MA_ORDER_ID DESC`;
    query += `\nFETCH FIRST 50 ROWS ONLY`;
  

  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? null : result.rows;
  
  
}

const plumberQuery = `SELECT 
PLUMBER_ID "plumberId" ,
PLUMBER_NAME "plumberName",
MOBILE_NO "mobileNo",
NID_NO "nidNo"
from XX_PLUMBER_REGISTRATION`;

export async function getPlumberStatusInfo(context) {
  let query = plumberQuery;
  const binds = {};
  
  if (context.created_by) {
    binds.created_by = context.created_by;
    binds.status = context.status;
    query += `\nWHERE CREATED_BY = :created_by`;
    query += `\nAND STATUS = :status`;
    query += `\nORDER BY PLUMBER_ID DESC`;
    query += `\nFETCH FIRST 10 ROWS ONLY`;

  } 

  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? null : result.rows;
}


export const getOneNotification = async (context) => {

  let query = `SELECT 
        n.NOTIFICATION_ID "notificationId",
        n.EMPLOYEE_NUMBER "employeeNumber",
        n.CUSTOMER_NUMBER "customerNumber",
        n.CUSTOMER_NAME "customerName",
        n.ADDRESS "address",
        n.PRODUCT_TYPE "productType",
        n.ORDER_ID "orderId",
        n.ORDER_STATUS "orderStatus",
        n.ORDER_DATE "orderDate",
        n.MR_ID "mrID",
        n.MR_STATUS "mrStatus",
        n.MR_DATE "mrDate",
        n.NOTIFICATION_DATE "NoticeDate",
        n.VIEWED_STATUS "viewedStatus",
        n.VIEWED_STATUS "status",
        u.USRS_FNAME "viewedBy"
      FROM 
      XX_NOTIFICATION n
      LEFT JOIN NPL_SAUSERS u ON u.SAUSERS_ID = n.VIEWED_BY
    `;

  const binds = {};

  if (context.Notification_id) {
    binds.id = context.Notification_id;
    binds.created_by = context.created_by;

    query += `\nWHERE n.NOTIFICATION_ID = :id`;
    query += `\nAND n.EMPLOYEE_NUMBER = :created_by`;
  }

  const result = await simpleExecute(query, binds);
  return result.rows[0];
};

export async function getTotNotification(context) {
  if(context.created_by){
    let query = `SELECT COUNT(A.MA_ORDER_ID) TOTNOTICE FROM (SELECT DISTINCT OL.MA_ORDER_ID FROM XX_MOBILE_ORDER_LINES OL,XX_MOBILE_ORDER_HEADERS OH WHERE OL.MA_ORDER_ID = OH.MA_ORDER_ID  AND OL.SUGG_FG = 'E'AND OH.STATUS ='DRAFT')A`;
    const binds = {};

  const result = await simpleExecute(query, binds);
  return result.rows[0];
  }
  
}

export async function getZone(context) {
  if(context.created_by){
    let salesPersonId = context.created_by;
    let query = `select distinct DIVISION "division",DIV_ID "divId",ORG_ID "orgId"  from APPS.XX_CUSTOMER_SHIPPING_DETAILS@SALES where SALESREP_NUMBER = ${salesPersonId}`;
    const binds = {};

  const result = await simpleExecute(query, binds);
  return result.rows[0];
  }
  
}
export async function getDiv(context) {
  if(context.created_by){
    let salesPersonId = context.created_by;
    let query = `SELECT DIVISION "divName", DIV_ID "divId" FROM APPS.XX_CUSTOMER_SHIPPING_DETAILS@SALES WHERE SALESREP_NUMBER = ${salesPersonId}
    GROUP BY DIVISION,DIV_ID`;
    const binds = {};

  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? 0 : result.rows;
  }
  
}
export async function getZoneList(context) {
  if(context.created_by){
    let salesPersonId = context.created_by;
    let divisionId = context.division_id;
    let query = `SELECT ZONE "zoneName",ZONE_ID "zoneId" FROM APPS.XX_CUSTTERRSRZMDM_V@SALES 
    WHERE SALESREP_NUMBER = ${salesPersonId}
    AND DIV_ID = ${divisionId}
    AND END_DATE_ACTIVE IS NULL
    GROUP BY ZONE,ZONE_ID`;
    const binds = {};

  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? 0 : result.rows;
  }
  
}
export async function getBaseList(context) {
  if(context.created_by){
    let salesPersonId = context.created_by;
    let zoneId = context.zone_id;
    let query = `SELECT BASE "baseName",AREA_ID "baseId" FROM APPS.XX_CUSTTERRSRZMDM_V@SALES 
    WHERE SALESREP_NUMBER = ${salesPersonId}
    AND ZONE_ID = ${zoneId}
    AND END_DATE_ACTIVE IS NULL
     GROUP BY BASE,AREA_ID`;
    const binds = {};

  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? 0 : result.rows;
  }
  
}



export async function getTotalRequest(context) {
  let query = `SELECT COUNT (SUGG_FG) TOTAL_REQEST FROM XX_MOBILE_ORDER_LINES`;

  const binds = {};

  if (context.ma_order_id && context.ma_line_id) {
    binds.ma_order_id = context.ma_order_id;

    query += `\nWHERE MA_ORDER_ID = :ma_order_id`;
    query += `\nAND SUGG_FG IS NOT NULL`;
  }

  const result = await simpleExecute(query, binds);
  return result.rows[0];
  
}

const basePlumberHeaderQuery = `SELECT 
      PLUMBER_ID "plumberId",
      PLUMBER_NAME "plumberName",
      ENGLISH_NAME "englishName",
      DATE_OF_BIRTH "dateOfBirth",
      PRESENT_ADDRESS "presentAddress",
      PARMANENT_ADDRESS "parmenentAddress",
      MOBILE_NO "mobileNo",
      NID_NO "nidNo",
      ZONE "zone",
      STATUS "status",
      PLUMBER_TYPE "plumberTypeValue",
      PLUMBER_IMAGE "imageLink",
      WORKPLACE "workPlace",
      EXPERIENCE_YEAR "experienceYear",
      FAMILY_NAME "wifeName",
      MARRIED_STATUS "marrideStatus",
      MARRIGE_DAY "mirageDay",
      TRANSACTION_NO "transcationNo",
      TRANSACTION_TYPE "transType",
      EDUC_QUALIFICATION "educQualification",
      DIV_NAME "divName",
      ZONE "zoneName",
      BASE "baseName"
    FROM 
    XX_PLUMBER_REGISTRATION`;

export async function getPlumber(context) {
  let query = basePlumberHeaderQuery;
  const binds = {};

  if (context.plumber_id) {
    binds.plumber_id = context.plumber_id;
    query += `\nWHERE PLUMBER_ID = :plumber_id`;
  }

  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? null : result.rows[0];
}

export async function getTotalCancelRequest(context) {
  let query = `SELECT COUNT (SUGG_FG) TOTAL_CANCEL_REQEST FROM XX_MOBILE_ORDER_LINES`;

  const binds = {};

  if (context.ma_order_id && context.ma_line_id) {
    binds.ma_order_id = context.ma_order_id;

    query += `\nWHERE MA_ORDER_ID = :ma_order_id`;
    query += `\nAND SUGG_FG ='C'`;
  }

  const result = await simpleExecute(query, binds);
  return result.rows[0];
  
}

const getSpecialRequest = `SELECT DISTINCT
                                OL.MA_ORDER_ID"maOrderId",
                                OH.CUSTOMER_NAME "customerName",
                                OH.CUSTOMER_NUMBER "customerNumber",
                                OH.ORG_ID "orgId",
                                OH.SALESREP_NAME "salesrepName",
                                OH.DELIVERY_DATE "deliveryDate",
                                OH.ORDER_TYPE_NAME "orderTypeName",
                                OH.DISCOUNT "orderDiscount"
                                FROM XX_MOBILE_ORDER_LINES OL, XX_MOBILE_ORDER_HEADERS OH
                                  WHERE OL.MA_ORDER_ID = OH.MA_ORDER_ID`;


export async function getSpecialRequestOrders(context) {
  let query = getSpecialRequest;
  const binds = {};
  
  if (context.created_by && context.status) {
    binds.status = context.status;
    //binds.created_by = context.created_by;

    query += `\nAND OL.SUGG_FG = :status`;
    query += `\nAND OH.STATUS = 'DRAFT'`;
    query += `\nORDER BY OL.MA_ORDER_ID DESC`;
    query += `\nFETCH FIRST 50 ROWS ONLY`;

  } 
  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? null : result.rows;
}

export async function getSpecialRequestApproveOrders(context) {
  let query = getSpecialRequest;
  const binds = {};
  
  if (context.created_by && context.status =='S') {
    binds.status = context.status;
    binds.created_by = context.created_by;

    query += `\nAND OL.SUGG_FG = :status`;
    query += `\nAND OH.STATUS = 'DRAFT'`;
    query += `\nAND OL.ED_SUGG_APP_BY = :created_by`;
    query += `\nORDER BY OL.MA_ORDER_ID DESC`;
    query += `\nFETCH FIRST 50 ROWS ONLY`;

  } else if(context.created_by && context.status =='C'){
    binds.status = context.status;
    binds.created_by = context.created_by;

    query += `\nAND OL.SUGG_FG = :status`;
    query += `\nAND OH.STATUS = 'DRAFT'`;
    query += `\nAND OL.ED_SUGG_CAN_BY = :created_by`;
    query += `\nORDER BY OL.MA_ORDER_ID DESC`;
    query += `\nFETCH FIRST 50 ROWS ONLY`;
  }
  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? null : result.rows;
}



const baseLineQuery = `SELECT
      MA_LINE_ID "maLineId",
      MA_ORDER_ID "maOrderId",
      INVENTORY_ITEM_ID "invItemId",
      ITEM_CODE "itemCode",
      DESCRIPTION "description",
      QTY "qty",
      GROSS_PRICE "grossPrice",
      NET_PRICE "netPrice",
      USER_ENTERED_PRICE "userEnteredPrice",
      SUGG_PRICE "suggestPrice",
      DISCOUNT_PCT "discountPct",
      LINE_TOTAL_AMOUNT "lineTotalAmount",
      REMARKS "remarks"
    FROM 
      XX_MOBILE_ORDER_LINES`;

      // get special request order line
export async function getSpecReqLines(context) {
  let query = baseLineQuery;

  const binds = {};

  if (context.ma_order_id) {
    binds.ma_order_id = context.ma_order_id;
    binds.request_status = context.request_status;
    query += `\nWHERE MA_ORDER_ID = :ma_order_id`;
    query += `\nAND SUGG_FG = :request_status`;
    query += `\nAND LINE_STATUS IS NULL`;
  }

  query += `\nORDER BY MA_LINE_ID`;

  const result = await simpleExecute(query, binds);

  return result.rows.length === 0 ? null : result.rows;
}
// save plumber registration
const createPlumberRegistration = `INSERT INTO XX_PLUMBER_REGISTRATION (
  plumber_name,
  plumber_image,
  date_of_birth,
  present_address,
  parmanent_address,
  mobile_no,
  educ_qualification,
  workplace,
  experience_year,
  family_name,
  marrige_day,
  nid_no,
  zone,
  created_by,
  status,
  transaction_no,
  div_id,
  org_id,
  plumber_type,
  english_name,
  transaction_type,
  married_status,
  zone_id,
  base,
  base_id,
  div_name) 
  VALUES (
  :plumber_name,
  :plumber_image,
  :date_of_birth,
  :present_address,
  :parmanent_address,
  :mobile_no,
  :educ_qualification,
  :workplace,
  :experience_year,
  :family_name,
  :marrige_day,
  :nid_no,
  :zone,
  :created_by,
  :status,
  :transaction_no,
  :div_id,
  :org_id,
  :plumber_type,
  :english_name,
  :trans_type,
  :married_status,
  :zone_id,
  :base_name,
  :base_id,
  :div_name) returning plumber_id into :plumber_id`;
export async function savePlumberRegistration(context) {
  let query = createPlumberRegistration;
  const obj = Object.assign({}, context);

  obj.plumber_id = {
    dir: OracleDB.BIND_OUT,
    type: OracleDB.NUMBER,
  };

  const result = await simpleExecute(query, obj);

  obj.plumber_id = result.outBinds.plumber_id[0];
  return result.rowsAffected === 1 ? obj.plumber_id : null;
}

// save partial delivery qty

const createPartialDelivery = `INSERT INTO XX_PARTIAL_DELIVERY (
  ma_order_id,
  ma_line_id,
  partial_date,
  partial_qty,
  created_by,
  item_code) 
  VALUES (
  :ma_order_id,
  :ma_line_id,
  :partial_date,
  :partial_qty,
  :created_by,
  :item_code) returning partial_delivery_id into :partial_delivery_id`;

export async function savePartialDelivery(context) {
  let query = createPartialDelivery;
  const obj = Object.assign({}, context);

  obj.partial_delivery_id = {
    dir: OracleDB.BIND_OUT,
    type: OracleDB.NUMBER,
  };
  const result = await simpleExecute(query, obj);

  obj.partial_delivery_id = result.outBinds.partial_delivery_id[0];
  return result.rowsAffected === 1 ? obj.partial_delivery_id : null;
}

export async function updateLineRemineQty(context) {
  let query = `UPDATE  XX_MOBILE_ORDER_LINES`;
  const binds = {};

  //binds.ma_order_id = context.ma_order_id;
  binds.ma_line_id = context.ma_line_id;
  binds.sum_delivery_qty = context.sum_delivery_qty;
  binds.created_by = context.created_by;
  binds.per_deli_at = context.per_deli_at;

  query += `\nSET REMAIN_QTY = :sum_delivery_qty,
                  PER_DELI_BY =:created_by,
                  PER_DELI_AT =:per_deli_at
  `;

  query += `\nWHERE  ma_line_id = :ma_line_id`;

  const result = await simpleExecute(query, binds);
  return result.rowsAffected === 1 ? true : false;
}

// delete specail request single line
export async function deleteSpecReqOneLine(context) {
  let query = `UPDATE  XX_MOBILE_ORDER_LINES`;
  const binds = {};

  //binds.ma_order_id = context.ma_order_id;
  binds.ma_line_id = context.ma_line_id;
  binds.created_by = context.created_by;
  binds.ed_cancle_date = context.ed_cancle_date;

  query += `\nSET SUGG_FG = 'C',
                  ED_SUGG_CAN_BY =:created_by,
                  ED_SUGG_CAN_AT =:ed_cancle_date
                  `;

  query += `\nWHERE  ma_line_id = :ma_line_id`;

  const result = await simpleExecute(query, binds);
  return result.rowsAffected === 1 ? true : false;
}
// special request update order

export async function submitSpecReqOrder(context) {
  let query = `UPDATE XX_MOBILE_ORDER_HEADERS`;
  const binds = {};

  binds.ma_order_id = context.ma_order_id;
  binds.status = context.status;
  //binds.submissionDate = context.submissionDate;

  const lines = await getLines(context.ma_order_id); 
  //const updateL = await updateLine(context.ma_order_id); 

  query += `\nSET SUGG_FG = :status`;
  query += `\nWHERE ma_order_id = :ma_order_id`;

  const result = await simpleExecute(query, binds);
  return result.rowsAffected === 1 ? true : false;
}

export async function updateLine(context) {
  let query = `UPDATE  XX_MOBILE_ORDER_LINES`;
  const binds = {};

  //binds.ma_order_id = context.ma_order_id;
  binds.status = context.status;
  binds.ma_order_id = context.ma_order_id;
  binds.created_by = context.created_by;
  binds.ed_sugg_app_at = context.ed_sugg_app_at;
  //const approveBy = context.created_by

  query += `\nSET SUGG_FG = :status,
              ED_SUGG_APP_BY =:created_by,
              ED_SUGG_APP_AT =:ed_sugg_app_at
                  `;

  query += `\nWHERE  ma_order_id = :ma_order_id`;
  query += `\nAND  SUGG_FG = 'E'`;

  const result = await simpleExecute(query, binds);
  return result.rowsAffected > 0 ? true : false;
}

export async function cancelLine(context) {
  let query = `UPDATE  XX_MOBILE_ORDER_LINES`;
  const binds = {};

  //binds.ma_order_id = context.ma_order_id;
  binds.sugg_fg = context.sugg_fg;
  binds.ma_order_id = context.ma_order_id;
  binds.created_by = context.created_by;
  binds.ed_sugg_can_at = context.ed_sugg_can_at;

  query += `\nSET SUGG_FG = :sugg_fg,
              ED_SUGG_CAN_BY =:created_by,
              ED_SUGG_CAN_AT =:ed_sugg_can_at
                  `;

  query += `\nWHERE  ma_order_id = :ma_order_id`;
  query += `\nAND  SUGG_FG = 'E'`;

  const result = await simpleExecute(query, binds);
  return result.rowsAffected > 0 ? true : false;
}


export async function getLines(context) {
  let query = baseLineQuery;

  const binds = {};

  if (context.ma_order_id) {
    binds.ma_order_id = context.ma_order_id;
    query += `\nWHERE MA_ORDER_ID = :ma_order_id`;
  }

  query += `\nORDER BY MA_LINE_ID`;

  const result = await simpleExecute(query, binds);

  return result.rows.length === 0 ? null : result.rows;
}


export async function submitOrder(context) {
  let query = `UPDATE XX_MOBILE_ORDER_HEADERS`;
  const binds = {};

  binds.ma_order_id = context.ma_order_id;
  binds.sugg_fg = context.sugg_fg;

  //const lines = await getLines(context.ma_order_id); 

  query += `\nSET SUGG_FG = :sugg_fg`;
  query += `\nWHERE ma_order_id = :ma_order_id`;

  const result = await simpleExecute(query, binds);
  return result.rowsAffected === 1 ? true : false;
}

export async function updateOne(context) {
  let query = `UPDATE XX_MOBILE_ORDER_LINES`;
  const obj = Object.assign({}, context);


  if (obj.ma_order_id && obj.ma_line_id) {
    query += `\nSET
    SUGG_FG = 'S',
    ED_SUGG_APP_BY = :created_by,
    ED_SUGG_APP_AT = :ed_sugg_app_at
    WHERE
        MA_ORDER_ID = :ma_order_id AND MA_LINE_ID = :ma_line_id`;
  }

  const result = await simpleExecute(query, obj);
  return result.rowsAffected === 1 ? obj.ma_line_id : null;
}

export async function cancelPlumber(context) {
  let query = `UPDATE XX_PLUMBER_REGISTRATION`;
  const binds = {};

  binds.plumber_id = context.plumber_id;
  binds.status = context.status;
  binds.submissionDate = context.submissionDate;

  //const lines = await getLines(context.ma_order_id); 

  query += `\nSET status = :status,CAN_AT = :submissionDate`;
  query += `\nWHERE plumber_id = :plumber_id`;

  const result = await simpleExecute(query, binds);
  return result.rowsAffected === 1 ? true : false;
}
const getPlumberEditQuery = `SELECT 
      PLUMBER_ID "plumberId",
      PLUMBER_NAME "plumberName",
      ENGLISH_NAME "englishName",
      PLUMBER_IMAGE "plumberImageUrl",
      DATE_OF_BIRTH "dateOfBirth",
      PRESENT_ADDRESS "presentAddress",
      PARMANENT_ADDRESS "parmanentAddress",
      MOBILE_NO "mobileNo",
      EDUC_QUALIFICATION "educQualification",
      WORKPLACE "workPlace",
      EXPERIENCE_YEAR "exprienceYear",
      FAMILY_NAME "wifeName",
      MARRIGE_DAY "marrigeDay",
      NID_NO "nidNo",
      ZONE "zone",
      ZONE_ID "zoneId",
      BASE_ID "baseId",
      STATUS "status",
      TRANSACTION_NO "transactionNo",
      DIV_ID "divId",
      ORG_ID "orgId",
      PLUMBER_TYPE "plumberTypeValue"
    FROM 
    XX_PLUMBER_REGISTRATION`;
export async function getPlumberEditInfo(context) {
  let query = getPlumberEditQuery;
  const binds = {};

  if (context.plumber_id) {
    binds.plumber_id = context.plumber_id;
    query += `\nWHERE PLUMBER_ID = :plumber_id`;
  }

  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? null : result.rows[0];
}

export async function updatePlumber(context) {
  let query = `UPDATE XX_PLUMBER_REGISTRATION`;
  const binds = {};

  binds.plumber_id = context.plumber_id;
  binds.plumber_name = context.plumber_name;
  binds.plumber_image = context.plumber_image;
  binds.date_of_birth = context.date_of_birth;
  binds.present_address = context.present_address;
  binds.parmanent_address = context.parmanent_address;
  binds.mobile_no = context.mobile_no;
  binds.educ_qualification = context.educ_qualification;
  binds.workplace = context.workplace;
  binds.experience_year = context.experience_year;
  binds.family_name = context.family_name;
  binds.marrige_day = context.marrige_day;
  binds.nid_no = context.nid_no;
  binds.transaction_no = context.transaction_no;
  //binds.zone = context.zone;
  binds.updated_by = context.updated_by;
  binds.updated_at = context.updated_at;
  binds.plumber_type = context.plumber_type;
  binds.english_name = context.english_name;
  binds.trans_type = context.trans_type;
  binds.marride_status = context.marride_status;
  binds.div_id = context.div_id;
  binds.div_name = context.div_name;
  binds.zone_id = context.zone_id;
  binds.zone = context.zone;
  binds.base_id = context.base_id;
  binds.base_name = context.base_name;

  query += `\nSET PLUMBER_NAME = :plumber_name,
                  PLUMBER_IMAGE = :plumber_image,
                  DATE_OF_BIRTH = :date_of_birth,
                  PRESENT_ADDRESS = :present_address,
                  PARMANENT_ADDRESS = :parmanent_address,
                  MOBILE_NO = :mobile_no,
                  EDUC_QUALIFICATION = :educ_qualification,
                  WORKPLACE = :workplace,
                  EXPERIENCE_YEAR = :experience_year,
                  FAMILY_NAME = :family_name,
                  MARRIGE_DAY = :marrige_day,
                  NID_NO = :nid_no,
                  TRANSACTION_NO = :transaction_no,
                  UPDATED_BY = :updated_by,
                  UPATED_AT = :updated_at,
                  PLUMBER_TYPE = :plumber_type,
                  ENGLISH_NAME = :english_name,
                  TRANSACTION_TYPE = :trans_type,
                  MARRIED_STATUS = :marride_status,
                  DIV_ID = :div_id,
                  DIV_NAME = :div_name,
                  ZONE_ID = :zone_id,
                  ZONE = :zone,
                  BASE_ID = :base_id,
                  BASE = :base_name
                  `;
                  
  query += `\nWHERE PLUMBER_ID = :plumber_id`;
  const result = await simpleExecute(query, binds);
  return result.rowsAffected === 1 ? true : false;
}

const baseDeliveryDateLineQuery = `SELECT
      MA_LINE_ID "maLineId",
      PARTIAL_QTY "partialQty"
    FROM 
    XX_PARTIAL_DELIVERY`;
      
export async function getDeliveryLines(context) {
  let query = baseDeliveryDateLineQuery;

  const binds = {};

  if (context.ma_line_id) {
    binds.ma_line_id = context.ma_line_id;
    query += `\nWHERE MA_LINE_ID = :ma_line_id`;
  }

  query += `\nORDER BY PARTIAL_DELIVERY_ID`;

  const result = await simpleExecute(query, binds);

  return result.rows.length === 0 ? null : result.rows;
}

export async function requestPlumberList(context) {
  let query = plumberQuery;
  const binds = {};
  
  if (context.status) {
    binds.created_by = context.created_by;
    binds.status = context.status;
    //query += `\nWHERE CREATED_BY = :created_by`;
    query += `\nWHERE STATUS = :status`;
    query += `\nAND SALESREP_NUMBER = :created_by`;
    query += `\nORDER BY PLUMBER_ID DESC`;
    query += `\nFETCH FIRST 10 ROWS ONLY`;

  } 

  const result = await simpleExecute(query, binds);
  return result.rows.length === 0 ? null : result.rows;
}